/*******************************************************************************
*                                                                              *
*   NetBurner MOD5213 General Purpose Input/Output Header File                 *
*   gpio5213.h                                                                 *
*                                                                              *
*******************************************************************************/


////////////////////////////////////////////////////////////////////////////////
// GPIO Pin Assignment Register Definitions. All signals are referenced to their
// primary functions. Writing the complement of each of the following defined
// values associated with a signal in the register will configure the
// corresponding pin for GPIO.
//

//
// For use with port AS pin assignment register: sim.gpio.paspar.
//
#define GPIO_PAR_SCL         (   0x03 )   // Bit  1 -  0 - I2C Serial Clock
#define GPIO_PAR_SDA         (   0x0C )   // Bit  3 -  2 - I2C Serial Data

//
// For use with port QS pin assignment register: sim.gpio.pqspar.
//
#define GPIO_PAR_QSPI_DOUT   ( 0x0003 )   // Bit  1 -  0 - QSPI Data Out
#define GPIO_PAR_QSPI_DIN    ( 0x000C )   // Bit  3 -  2 - QSPI Data In
#define GPIO_PAR_QSPI_CLK    ( 0x0030 )   // Bit  5 -  4 - QSPI Clock
#define GPIO_PAR_QSPI_CS0    ( 0x00C0 )   // Bit  7 -  6 - QSPI Chip Select 0
#define GPIO_PAR_QSPI_CS1    ( 0x0300 )   // Bit  9 -  8 - QSPI Chip Select 1
#define GPIO_PAR_QSPI_CS2    ( 0x0C00 )   // Bit 11 - 10 - QSPI Chip Select 2

//
// For use with port TA pin assignment register: sim.gpio.ptapar.
//
#define GPIO_PAR_GPT0        (   0x03 )   // Bit  1 -  0 - Gen. Purpose Timer 0
#define GPIO_PAR_GPT1        (   0x0C )   // Bit  3 -  2 - Gen. Purpose Timer 1
#define GPIO_PAR_GPT2        (   0x30 )   // Bit  5 -  4 - Gen. Purpose Timer 2
#define GPIO_PAR_GPT3        (   0xC0 )   // Bit  7 -  6 - Gen. Purpose Timer 3

//
// For use with port TC pin assignment register: sim.gpio.ptcpar.
//
#define GPIO_PAR_DTIN0       (   0x03 )   // Bit  1 -  0 - DMA Timer Input 0
#define GPIO_PAR_DTIN1       (   0x0C )   // Bit  3 -  2 - DMA Timer Input 1
#define GPIO_PAR_DTIN2       (   0x30 )   // Bit  5 -  4 - DMA Timer Input 2
#define GPIO_PAR_DTIN3       (   0xC0 )   // Bit  7 -  6 - DMA Timer Input 3

//
// For use with port UB pin assignment register: sim.gpio.pubpar.
//
#define GPIO_PAR_UTXD1       (   0x03 )   // Bit  1 -  0 - UART 1 - Transmit
#define GPIO_PAR_URXD1       (   0x0C )   // Bit  3 -  2 - UART 1 - Receive
#define GPIO_PAR_URTS1       (   0x30 )   // Bit  5 -  4 - UART 1 - Request to Send
#define GPIO_PAR_UCTS1       (   0xC0 )   // Bit  7 -  6 - UART 1 - Clear to Send

//
// For use with port UA pin assignment register: sim.gpio.puapar.
//
#define GPIO_PAR_UTXD0       (   0x03 )   // Bit  1 -  0 - UART 0 - Transmit
#define GPIO_PAR_URXD0       (   0x0C )   // Bit  3 -  2 - UART 0 - Receive

//
// For use with port AN pin assignment register: sim.gpio.panpar.
//
#define GPIO_PAR_AN0         (   0x01 )   // Bit       0 - Analog Input 0
#define GPIO_PAR_AN1         (   0x02 )   // Bit       1 - Analog Input 1
#define GPIO_PAR_AN2         (   0x04 )   // Bit       2 - Analog Input 2
#define GPIO_PAR_AN3         (   0x08 )   // Bit       3 - Analog Input 3
#define GPIO_PAR_AN4         (   0x10 )   // Bit       4 - Analog Input 4
#define GPIO_PAR_AN5         (   0x20 )   // Bit       5 - Analog Input 5
#define GPIO_PAR_AN6         (   0x40 )   // Bit       6 - Analog Input 6
#define GPIO_PAR_AN7         (   0x80 )   // Bit       7 - Analog Input 7

//
// For use with port NQ pin assignment register: sim.gpio.pnqpar.
//
#define GPIO_PAR_IRQ1        (   0x03 )   // Bit  1 -  0 - Interrupt Request 1
#define GPIO_PAR_IRQ4        (   0x10 )   // Bit       4 - Interrupt Request 4
#define GPIO_PAR_IRQ7        (   0x80 )   // Bit       7 - Interrupt Request 7


////////////////////////////////////////////////////////////////////////////////
// GPIO Port Data Direction Register, Port Output Data Register, Port Pin Data/
// Set Data Register, and Port Clear Output Data Register Definitions. The
// following defined values are only for use on corresponding pins that are
// configured for GPIO.
//
// Port Data Direction Register (DDRxx)
// Write: 0 = Input, 1 = Output
// Read: The current values in the register
//
// Port Output Data Register (PORTxx)
// Write: 0 = Low, 1 = High
// Read: The current values in the register (not the port pin values)
//
// Port Pin Data/Set Data Register (SETxx)
// Write: 0 = No Effect, 1 = High (for corresponding bits in PORTxx)
// Read: The current state of the pins
//
// Port Clear Output Data Register (CLRxx)
// Write: 0 = Low (for corresponding bits in PORTxx), 1 = No Effect
// Read: Always return zeros
//

//
// For use with sim.gpio.ddras, sim.gpio.portas, sim.gpio.setas, and
// sim.gpio.clras.
//
#define GPIO_PIN_SCL         (   0x01 )   // Bit 0 - I2C Serial Clock
#define GPIO_PIN_SDA         (   0x02 )   // Bit 1 - I2C Serial Data

//
// For use with sim.gpio.ddrqs, sim.gpio.portqs, sim.gpio.setqs, and
// sim.gpio.clrqs.
//
#define GPIO_PIN_QSPI_DOUT   (   0x01 )   // Bit 0 - QSPI Data Out
#define GPIO_PIN_QSPI_DIN    (   0x02 )   // Bit 1 - QSPI Data In
#define GPIO_PIN_QSPI_CLK    (   0x04 )   // Bit 2 - QSPI Clock
#define GPIO_PIN_QSPI_CS0    (   0x08 )   // Bit 3 - QSPI Chip Select 0
#define GPIO_PIN_QSPI_CS1    (   0x10 )   // Bit 4 - QSPI Chip Select 1
#define GPIO_PIN_QSPI_CS2    (   0x20 )   // Bit 5 - QSPI Chip Select 2

//
// For use with sim.gpio.ddrta, sim.gpio.portta, sim.gpio.setta, and
// sim.gpio.clrta.
//
#define GPIO_PIN_GPT0        (   0x01 )   // Bit 0 - Gen. Purpose Timer 0
#define GPIO_PIN_GPT1        (   0x02 )   // Bit 1 - Gen. Purpose Timer 1
#define GPIO_PIN_GPT2        (   0x04 )   // Bit 2 - Gen. Purpose Timer 2
#define GPIO_PIN_GPT3        (   0x08 )   // Bit 3 - Gen. Purpose Timer 3

//
// For use with sim.gpio.ddrtc, sim.gpio.porttc, sim.gpio.settc, and
// sim.gpio.clrtc.
//
#define GPIO_PIN_DTIN0       (   0x01 )   // Bit 0 - DMA Timer Input 0
#define GPIO_PIN_DTIN1       (   0x02 )   // Bit 1 - DMA Timer Input 1
#define GPIO_PIN_DTIN2       (   0x04 )   // Bit 2 - DMA Timer Input 2
#define GPIO_PIN_DTIN3       (   0x08 )   // Bit 3 - DMA Timer Input 3

//
// For use with sim.gpio.ddrub, sim.gpio.portub, sim.gpio.setub, and
// sim.gpio.clrub.
//
#define GPIO_PIN_UTXD1       (   0x01 )   // Bit 0 - UART 1 - Transmit
#define GPIO_PIN_URXD1       (   0x02 )   // Bit 1 - UART 1 - Receive
#define GPIO_PIN_URTS1       (   0x04 )   // Bit 2 - UART 1 - Request to Send
#define GPIO_PIN_UCTS1       (   0x08 )   // Bit 3 - UART 1 - Clear to Send

//
// For use with sim.gpio.ddrua, sim.gpio.portua, sim.gpio.setua, and
// sim.gpio.clrua.
//
#define GPIO_PIN_UTXD0       (   0x01 )   // Bit 0 - UART 0 - Transmit
#define GPIO_PIN_URXD0       (   0x02 )   // Bit 1 - UART 0 - Receive

//
// For use with sim.gpio.ddran, sim.gpio.portan, sim.gpio.setan, and
// sim.gpio.clran.
//
#define GPIO_PIN_AN0         (   0x01 )   // Bit 0 - Analog Input 0
#define GPIO_PIN_AN1         (   0x02 )   // Bit 1 - Analog Input 1
#define GPIO_PIN_AN2         (   0x04 )   // Bit 2 - Analog Input 2
#define GPIO_PIN_AN3         (   0x08 )   // Bit 3 - Analog Input 3
#define GPIO_PIN_AN4         (   0x10 )   // Bit 4 - Analog Input 4
#define GPIO_PIN_AN5         (   0x20 )   // Bit 5 - Analog Input 5
#define GPIO_PIN_AN6         (   0x40 )   // Bit 6 - Analog Input 6
#define GPIO_PIN_AN7         (   0x80 )   // Bit 7 - Analog Input 7

//
// For use with sim.gpio.ddrnq, sim.gpio.portnq, sim.gpio.setnq, and
// sim.gpio.clrnq.
//
#define GPIO_PIN_IRQ1        (   0x02 )   // Bit 1 - Interrupt Request 1
#define GPIO_PIN_IRQ4        (   0x10 )   // Bit 4 - Interrupt Request 4
#define GPIO_PIN_IRQ7        (   0x80 )   // Bit 7 - Interrupt Request 7
